@@ -17,6 +17,8 @@
     along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
+#include <utility>
+
 #include "qgamacontrolpanel.h"
 
 #include <QMenu>
@@ -166,6 +168,9 @@ void QGamaControlPanel::build_menus()
     actionDbConnect = menuDb->addAction(tr("&Connect to Database"));
     connect(actionDbConnect, SIGNAL(triggered()),
             SLOT(on_action_Connect_to_database_triggered()));
+
+    if (actionDbConnect->isVisible()) menuDb->addSeparator();
+
     actionImportConf = menuDb->addAction(tr("&Import Configuration File"));
     connect(actionImportConf, SIGNAL(triggered()),
             SLOT(on_action_Import_configuration_file_triggered()));
@@ -221,7 +226,7 @@ void QGamaControlPanel::build_menus()
     connect (actionAdjAdjustment, SIGNAL(triggered()),
              SLOT(on_action_Network_adjustment_triggered()));
 
-    // ****** end of adjutment menu
+    // ****** end of adjustment menu
 
 
     QMenu* menuTools = new QMenu(tr("&Tools"), this);
@@ -290,7 +295,7 @@ void QGamaControlPanel::closeEvent(QCloseEvent * event)
     {
         event->accept();
         QGamaHelp::get()->close();
-        for (const auto& p : qAsConst(localPluginsList)) p->close();
+        for (const auto& p : std::as_const(localPluginsList)) p->close();
     }
     else if (dialogCode == QMessageBox::YesAll)
     {
@@ -302,7 +307,7 @@ void QGamaControlPanel::closeEvent(QCloseEvent * event)
 
         event->accept();
         QGamaHelp::get()->close();
-        for (const auto& p : qAsConst(localPluginsList)) p->close();
+        for (const auto& p : std::as_const(localPluginsList)) p->close();
     }
     else
     {
@@ -347,6 +352,8 @@ void QGamaControlPanel::disable_input_data(bool yes)
     actionAdjAdjustment->setEnabled(yes);
     actionAdjResultsLanguage->setEnabled(yes);
 
+    actionDbConnect->setVisible(!yes);
+
     if (yes) ShowMessage(tr("Connected to database"));
 }
 
@@ -447,6 +454,7 @@ void QGamaControlPanel::on_action_About_qgama_triggered()
                   QString(tr("Based on <a href='http://www.gnu.org/software/gama'>"
                              "GNU gama</a> version %1")
                          ).arg(GNU_gama::GNU_gama_version().c_str()) +
+                  "  and Qt " + QString(qVersion()) +
                   "</p>"
 
                   "<p>This program is free software: you can redistribute it and/or modify "
